pub fn get_admin_access_keys() -> AccessKeysExpand description
Returns all admin access keys of this satellite.
Filters the full access key list to only those with ControllerScope::Admin.
Admin access keys never expire and are also controllers of the canister
as defined by the Internet Computer.