Function is_admin_controller
Source pub fn is_admin_controller(
id: Principal,
access_keys: &HashMap<Principal, AccessKey>,
) -> bool
Checks if an id is an admin access key and a controller has known by the Internet Computer.
Arguments
id: Principal e.g. of the caller.
access_keys: Reference to the current set of access_keys.
Returns
true if the id is an admin access key and a controller, otherwise false.